@@ -14,8 +14,6 @@
 
 #include <glib/gi18n.h>
 
-#include <bonobo/bonobo-main.h>
-
 #include <libegg/eggdesktopfile.h>
 #include <libegg/eggsmclient.h>
 
@@ -80,11 +78,6 @@ main (int argc, char **argv)
 
 	gtk_init (&argc, &argv);
 
-	if (!bonobo_init (&argc, argv)) {
-		g_printerr ("Cannot initialize bonobo.\n");
-		return 1;
-	}
-
 	error = NULL;
 	if (!g_option_context_parse (context, &argc, &argv, &error)) {
 		g_printerr ("%s\n", error->message);
