@@ -35,6 +35,7 @@
 #include "panel-globals.h"
 #include "panel-toplevel.h"
 #include "panel-util.h"
+#include "panel-force-quit.h"
 #include "panel-run-dialog.h"
 #include "panel-menu-button.h"
 #include "panel-menu-bar.h"
@@ -87,7 +88,7 @@ static void
 panel_action_protocol_kill_dialog (GdkScreen *screen,
 				   guint32    activate_time)
 {
-	panel_run_dialog_present (screen, activate_time);
+	panel_force_quit (screen, activate_time);
 }
 
 static GdkFilterReturn
