@@ -26,9 +26,10 @@
 
 #include "panel-stock-icons.h"
 
-#include <gtk/gtkstock.h>
-#include <gtk/gtkiconfactory.h>
 #include <glib/gi18n.h>
+#include <gtk/gtk.h>
+
+#include "panel-icon-names.h"
 
 static GtkIconSize panel_menu_icon_size = 0;
 static GtkIconSize panel_menu_bar_icon_size = 0;
@@ -51,7 +52,7 @@ typedef struct {
 } PanelStockIcon;
 
 static PanelStockIcon stock_icons [] = {
-	{ PANEL_STOCK_FORCE_QUIT,          "panel-force-quit" }
+	{ PANEL_STOCK_FORCE_QUIT, PANEL_ICON_FORCE_QUIT }
 };
 
 static void
@@ -126,7 +127,9 @@ panel_init_stock_icons_and_items (void)
 						       PANEL_DEFAULT_MENU_ICON_SIZE,
 						       PANEL_DEFAULT_MENU_ICON_SIZE);
 
-	panel_menu_bar_icon_size = gtk_icon_size_register ("panel-foobar", 20, 20);
+	panel_menu_bar_icon_size = gtk_icon_size_register ("panel-foobar",
+							   PANEL_DEFAULT_MENU_BAR_ICON_SIZE,
+							   PANEL_DEFAULT_MENU_BAR_ICON_SIZE);
 
 	factory = gtk_icon_factory_new ();
 	gtk_icon_factory_add_default (factory);
