@@ -196,7 +196,7 @@ add_all_move_bindings (PanelWidget *panel)
 		 * by setting the focus to the PanelWidget for the
 		 * duration of the move.
 		 */
-		GTK_WIDGET_SET_FLAGS (panel, GTK_CAN_FOCUS);
+		gtk_widget_set_can_focus (GTK_WIDGET (panel), TRUE);
 		gtk_widget_grab_focus (GTK_WIDGET (panel));
 		saved_focus_widget = focus_widget;
 	}
@@ -205,22 +205,22 @@ add_all_move_bindings (PanelWidget *panel)
 static void
 panel_widget_force_grab_focus (GtkWidget *widget)
 {
-	gboolean can_focus = GTK_WIDGET_CAN_FOCUS (widget);
+	gboolean can_focus = gtk_widget_get_can_focus (widget);
 	/*
 	 * This follows what gtk_socket_claim_focus() does
 	 */
 	if (!can_focus)
-		GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_FOCUS);
+		gtk_widget_set_can_focus (widget, TRUE);
 	gtk_widget_grab_focus (widget);
 	if (!can_focus)
-		GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
+		gtk_widget_set_can_focus (widget, FALSE);
 }
 
 static void
 panel_widget_reset_saved_focus (PanelWidget *panel)
 {
 	if (saved_focus_widget) {
-		GTK_WIDGET_UNSET_FLAGS (panel, GTK_CAN_FOCUS);
+		gtk_widget_set_can_focus (GTK_WIDGET (panel), FALSE);
 		panel_widget_force_grab_focus (saved_focus_widget);
 		saved_focus_widget = NULL;
 	}
@@ -442,7 +442,7 @@ remove_panel_from_forbidden(PanelWidget *panel, PanelWidget *r)
 				   PANEL_APPLET_FORBIDDEN_PANELS,
 				   list);
 	}
-	parent_panel = panel->master_widget->parent;
+	parent_panel = gtk_widget_get_parent (panel->master_widget);
 	if (parent_panel)
 		remove_panel_from_forbidden(PANEL_WIDGET(parent_panel), r);
 }
@@ -468,7 +468,7 @@ add_panel_to_forbidden(PanelWidget *panel, PanelWidget *r)
 				   PANEL_APPLET_FORBIDDEN_PANELS,
 				   list);
 	}
-	parent_panel = panel->master_widget->parent;
+	parent_panel = gtk_widget_get_parent (panel->master_widget);
 	if (parent_panel)
 		add_panel_to_forbidden(PANEL_WIDGET(parent_panel), r);
 }
@@ -498,7 +498,7 @@ panel_widget_reset_focus (GtkContainer *container,
 {
 	PanelWidget *panel = PANEL_WIDGET (container);
 
-	if (container->focus_child == widget) {
+	if (gtk_container_get_focus_child (container) == widget) {
 		GList *children;
 
 		children = gtk_container_get_children (container);
@@ -1174,7 +1174,7 @@ panel_widget_right_stick(PanelWidget *panel,int old_size)
 
 	ad = list->data;
 	do { 
-		i = ad->constrained;
+		i = ad->pos;
 		ad->pos = ad->constrained = pos--;
 		ad->cells = 1;
 		prev = list;
@@ -1182,7 +1182,7 @@ panel_widget_right_stick(PanelWidget *panel,int old_size)
 		if(!list)
 			break;
 		ad = list->data;
-	} while(ad->constrained + ad->cells == i);
+	} while(ad->pos + ad->cells == i);
 
 	for (list = prev; list; list = list->next)
 		emit_applet_moved (panel, list->data);
@@ -1308,21 +1308,24 @@ queue_resize_on_all_applets(PanelWidget *panel)
 static void
 panel_widget_set_background_region (PanelWidget *panel)
 {
-	GtkWidget *widget;
-	int       origin_x = -1, origin_y = -1;
+	GtkWidget     *widget;
+	int            origin_x = -1, origin_y = -1;
+	GtkAllocation  allocation;
 
 	widget = GTK_WIDGET (panel);
 
-	if (!GTK_WIDGET_REALIZED (widget))
+	if (!gtk_widget_get_realized (widget))
 		return;
 
-	gdk_window_get_origin (widget->window, &origin_x, &origin_y);
+	gdk_window_get_origin (gtk_widget_get_window (widget), &origin_x, &origin_y);
+
+	gtk_widget_get_allocation (widget, &allocation);
 
 	panel_background_change_region (
 		&panel->background, panel->orient,
 		origin_x, origin_y,
-		widget->allocation.width,
-		widget->allocation.height);
+		allocation.width,
+		allocation.height);
 }
 
 static void
@@ -1342,9 +1345,9 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 	old_size = panel->size;
 	ltr = gtk_widget_get_direction (widget) == GTK_TEXT_DIR_LTR;
 	
-	widget->allocation = *allocation;
-	if (GTK_WIDGET_REALIZED (widget))
-		gdk_window_move_resize (widget->window,
+	gtk_widget_set_allocation (widget, allocation);
+	if (gtk_widget_get_realized (widget))
+		gdk_window_move_resize (gtk_widget_get_window (widget),
 					allocation->x, 
 					allocation->y,
 					allocation->width, 
@@ -1523,9 +1526,10 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 gboolean
 panel_widget_is_cursor(PanelWidget *panel, int overlap)
 {
-	int x,y;
-	int w,h;
-	GtkWidget *widget;
+	GtkWidget     *widget;
+	GtkAllocation allocation;
+	int           x,y;
+	int           w,h;
 
 	g_return_val_if_fail(PANEL_IS_WIDGET(panel),FALSE);
 
@@ -1533,12 +1537,14 @@ panel_widget_is_cursor(PanelWidget *panel, int overlap)
 	
 	if(!widget ||
 	   !GTK_IS_WIDGET(widget) ||
-	   !GTK_WIDGET_VISIBLE(widget))
+	   !gtk_widget_get_visible(widget))
 		return FALSE;
 
 	gtk_widget_get_pointer(widget, &x, &y);
-	w = widget->allocation.width;
-	h = widget->allocation.height;
+
+	gtk_widget_get_allocation (widget, &allocation);
+	w = allocation.width;
+	h = allocation.height;
 
 	if((x+overlap)>=0 &&
 	   (x-overlap)<=w &&
@@ -1552,22 +1558,36 @@ static void
 panel_widget_style_set (GtkWidget *widget,
 			GtkStyle  *previous_style)
 {
-	if (GTK_WIDGET_REALIZED (widget))
+	GtkStyle     *style;
+	GtkStateType  state;
+
+	if (gtk_widget_get_realized (widget)) {
+		style = gtk_widget_get_style (widget);
+		state = gtk_widget_get_state (widget);
+
 		panel_background_set_default_style (
 			&PANEL_WIDGET (widget)->background,
-			&widget->style->bg [GTK_WIDGET_STATE (widget)],
-			widget->style->bg_pixmap [GTK_WIDGET_STATE (widget)]);
+			&style->bg [state],
+			style->bg_pixmap [state]);
+	}
 }
 
 static void
 panel_widget_state_changed (GtkWidget    *widget,
 			    GtkStateType  previous_state)
 {
-	if (GTK_WIDGET_REALIZED (widget))
+	GtkStyle     *style;
+	GtkStateType  state;
+
+	if (gtk_widget_get_realized (widget)) {
+		style = gtk_widget_get_style (widget);
+		state = gtk_widget_get_state (widget);
+
 		panel_background_set_default_style (
 			&PANEL_WIDGET (widget)->background,
-			&widget->style->bg [GTK_WIDGET_STATE (widget)],
-			widget->style->bg_pixmap [GTK_WIDGET_STATE (widget)]);
+			&style->bg [state],
+			style->bg_pixmap [state]);
+	}
 }
 
 static gboolean
@@ -1583,23 +1603,30 @@ toplevel_configure_event (GtkWidget         *widget,
 static void
 panel_widget_realize (GtkWidget *widget)
 {
-	PanelWidget *panel = (PanelWidget *) widget;
+	PanelWidget  *panel = (PanelWidget *) widget;
+	GdkWindow    *window;
+	GtkStyle     *style;
+	GtkStateType  state;
 
 	g_signal_connect (panel->toplevel, "configure-event",
 			  G_CALLBACK (toplevel_configure_event), panel);
 
 	GTK_WIDGET_CLASS (panel_widget_parent_class)->realize (widget);
 
+	window = gtk_widget_get_window (widget);
+	style = gtk_widget_get_style (widget);
+	state = gtk_widget_get_state (widget);
+
 	/* For auto-hidden panels with a colored background, we need native
 	 * windows to avoid some uglyness on unhide */
-	gdk_window_ensure_native (widget->window);
+	gdk_window_ensure_native (window);
 
 	panel_background_set_default_style (
 		&panel->background,
-		&widget->style->bg [GTK_WIDGET_STATE (widget)],
-		widget->style->bg_pixmap [GTK_WIDGET_STATE (widget)]);
+		&style->bg [state],
+		style->bg_pixmap [state]);
 
-	panel_background_realized (&panel->background, widget->window);
+	panel_background_realized (&panel->background, window);
 }
 
 static void
@@ -1731,8 +1758,8 @@ panel_widget_new (PanelToplevel  *toplevel,
 
 	panel = g_object_new (PANEL_TYPE_WIDGET, NULL);
 
-        GTK_WIDGET_UNSET_FLAGS (panel, GTK_NO_WINDOW);
-        GTK_WIDGET_SET_FLAGS (panel, GTK_CAN_FOCUS);
+        gtk_widget_set_has_window (GTK_WIDGET (panel), TRUE);
+        gtk_widget_set_can_focus (GTK_WIDGET (panel), TRUE);
 
 	panel->orient = orient;
 	panel->sz = sz;
@@ -1829,6 +1856,8 @@ panel_widget_applet_drag_start (PanelWidget *panel,
 				int          drag_off,
 				guint32      time_)
 {
+	GdkWindow *window;
+
 	g_return_if_fail (PANEL_IS_WIDGET (panel));
 	g_return_if_fail (GTK_IS_WIDGET (applet));
 
@@ -1843,13 +1872,15 @@ panel_widget_applet_drag_start (PanelWidget *panel,
 	panel_toplevel_push_autohide_disabler (panel->toplevel);
 
 	gtk_grab_add (applet);
-	if (applet->window) {
+
+	window = gtk_widget_get_window (applet);
+	if (window) {
 		GdkGrabStatus  status;
 		GdkCursor     *fleur_cursor;
 
 		fleur_cursor = gdk_cursor_new (GDK_FLEUR);
 
-		status = gdk_pointer_grab (applet->window, FALSE,
+		status = gdk_pointer_grab (window, FALSE,
 					   APPLET_EVENT_MASK, NULL,
 					   fleur_cursor, time_);
 
@@ -2109,7 +2140,7 @@ panel_widget_applet_move_to_cursor (PanelWidget *panel)
 		}
 	}
 
-	gdk_window_get_pointer(GTK_WIDGET(panel)->window,
+	gdk_window_get_pointer(gtk_widget_get_window (GTK_WIDGET(panel)),
 			       NULL,NULL,&mods);
 
 	movement = PANEL_SWITCH_MOVE;
@@ -2143,7 +2174,8 @@ panel_widget_applet_move_to_cursor (PanelWidget *panel)
 static int
 move_timeout_handler(gpointer data)
 {
-	PanelWidget *panel = data;
+	PanelWidget   *panel = data;
+
 	g_return_val_if_fail(PANEL_IS_WIDGET(data),FALSE);
 
 	if(been_moved &&
@@ -2155,15 +2187,18 @@ move_timeout_handler(gpointer data)
 	been_moved = FALSE;
 
 	if(panel->currently_dragged_applet && repeat_if_outside) {
-		int x,y;
-		int w,h;
-		GtkWidget *widget;
+		GtkWidget     *widget;
+		GtkAllocation  allocation;
+		int            x,y;
+		int            w,h;
 
 		widget = panel->currently_dragged_applet->applet;
 
 		gtk_widget_get_pointer(widget, &x, &y);
-		w = widget->allocation.width;
-		h = widget->allocation.height;
+
+		gtk_widget_get_allocation (widget, &allocation);
+		w = allocation.width;
+		h = allocation.height;
 
 		/* if NOT inside return TRUE, this means we will be
 		 * kept inside the timeout until we hit the damn widget
@@ -2196,12 +2231,15 @@ static gboolean
 panel_widget_applet_button_press_event (GtkWidget      *widget,
 					GdkEventButton *event)
 {
+	GtkWidget   *parent;
 	PanelWidget *panel;
 	guint32      event_time;
-	
-	g_return_val_if_fail (PANEL_IS_WIDGET (widget->parent), FALSE);
 
-	panel = PANEL_WIDGET (widget->parent);
+	parent = gtk_widget_get_parent (widget);
+
+	g_return_val_if_fail (PANEL_IS_WIDGET (parent), FALSE);
+
+	panel = PANEL_WIDGET (parent);
 
 	/* don't propagate this event */
 	if (panel->currently_dragged_applet) {
@@ -2232,11 +2270,14 @@ static gboolean
 panel_widget_applet_button_release_event (GtkWidget      *widget,
 					  GdkEventButton *event)
 {
+	GtkWidget   *parent;
 	PanelWidget *panel;
-	
-	g_return_val_if_fail (PANEL_IS_WIDGET (widget->parent), FALSE);
 
-	panel = PANEL_WIDGET (widget->parent);
+	parent = gtk_widget_get_parent (widget);
+
+	g_return_val_if_fail (PANEL_IS_WIDGET (parent), FALSE);
+
+	panel = PANEL_WIDGET (parent);
 	
 	/* don't propagate this event */
 	if (panel->currently_dragged_applet) {
@@ -2255,14 +2296,17 @@ static gboolean
 panel_widget_applet_motion_notify_event (GtkWidget *widget,
 					 GdkEvent  *event)
 {
+	GtkWidget   *parent;
 	PanelWidget *panel;
-	
-	g_return_val_if_fail (PANEL_IS_WIDGET (widget->parent), FALSE);
+
+	parent = gtk_widget_get_parent (widget);
+
+	g_return_val_if_fail (PANEL_IS_WIDGET (parent), FALSE);
 
 	if (gdk_event_get_screen (event) != gtk_widget_get_screen (widget))
 		return FALSE;
 
-	panel = PANEL_WIDGET (widget->parent);
+	panel = PANEL_WIDGET (parent);
 	
 	schedule_try_move (panel, FALSE);
 
@@ -2273,11 +2317,14 @@ static gboolean
 panel_widget_applet_key_press_event (GtkWidget   *widget,
 				     GdkEventKey *event)
 {
+	GtkWidget   *parent;
 	PanelWidget *panel;
 	
-	g_return_val_if_fail (PANEL_IS_WIDGET (widget->parent), FALSE);
+	parent = gtk_widget_get_parent (widget);
 
-	panel = PANEL_WIDGET (widget->parent);
+	g_return_val_if_fail (PANEL_IS_WIDGET (parent), FALSE);
+
+	panel = PANEL_WIDGET (parent);
 
 	if (!panel_applet_in_drag)
 		return FALSE;
@@ -2330,7 +2377,7 @@ bind_applet_events(GtkWidget *widget, gpointer data)
 	 * GtkEventBox) for processing by us.
 	 */
 	
-	if (!GTK_WIDGET_NO_WINDOW(widget))
+	if (gtk_widget_get_has_window (widget))
 		g_signal_connect (G_OBJECT(widget), "event",
 				  G_CALLBACK (panel_sub_event_handler),
 				  data);
@@ -2344,15 +2391,17 @@ static void
 panel_widget_applet_destroy (GtkWidget *applet, gpointer data)
 {
 	AppletData *ad;
+	GtkWidget  *parent;
 
 	g_return_if_fail (GTK_IS_WIDGET (applet));
 
 	ad = g_object_get_data (G_OBJECT (applet), PANEL_APPLET_DATA);
 	g_object_set_data (G_OBJECT (applet), PANEL_APPLET_DATA, NULL);
 
+	parent = gtk_widget_get_parent (applet);
 	/*if it wasn't yet removed*/
-	if(applet->parent) {
-		PanelWidget *panel = PANEL_WIDGET (applet->parent);
+	if(parent) {
+		PanelWidget *panel = PANEL_WIDGET (parent);
 
 		if (panel->currently_dragged_applet == ad)
 			panel_widget_applet_drag_end (panel);
@@ -2580,15 +2629,15 @@ panel_widget_reparent (PanelWidget *old_panel,
 	ad->no_die++;
 
 	panel_widget_reset_saved_focus (old_panel);
-	if (GTK_CONTAINER (old_panel)->focus_child == applet)
+	if (gtk_container_get_focus_child (GTK_CONTAINER (old_panel)) == applet)
 		focus_widget = gtk_window_get_focus (GTK_WINDOW (old_panel->toplevel));
 	gtk_widget_reparent (applet, GTK_WIDGET (new_panel));
 
-	if (info && info->type == PANEL_OBJECT_BONOBO)
+	if (info && info->type == PANEL_OBJECT_APPLET)
 		panel_applet_frame_set_panel (PANEL_APPLET_FRAME (ad->applet), new_panel);
 
-	if (GTK_WIDGET_CAN_FOCUS (new_panel))
-		GTK_WIDGET_UNSET_FLAGS (new_panel, GTK_CAN_FOCUS);
+	if (gtk_widget_get_can_focus (GTK_WIDGET (new_panel)))
+		gtk_widget_set_can_focus (GTK_WIDGET (new_panel), FALSE);
 	if (focus_widget) {
 		panel_widget_force_grab_focus (focus_widget);
 	} else {
@@ -2793,8 +2842,8 @@ static gboolean
 panel_widget_real_focus (GtkWidget        *widget,
                          GtkDirectionType  direction)
 {
-	if (GTK_WIDGET_CAN_FOCUS (widget) && GTK_FIXED (widget)->children) {
-		GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
+	if (gtk_widget_get_can_focus (widget) && gtk_container_get_children (GTK_CONTAINER (widget))) {
+		gtk_widget_set_can_focus (widget, FALSE);
 	}
 	return GTK_WIDGET_CLASS (panel_widget_parent_class)->focus (widget, direction);
 }
@@ -2812,7 +2861,7 @@ panel_widget_focus (PanelWidget *panel_widget)
 	 * on the panel as it is unset when this function is called.
 	 */
 	gtk_container_set_focus_child (GTK_CONTAINER (panel_widget), NULL);
-	GTK_WIDGET_SET_FLAGS (panel_widget, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (GTK_WIDGET (panel_widget), TRUE);
 	gtk_widget_grab_focus (GTK_WIDGET (panel_widget));
 }
 
