@@ -22,10 +22,6 @@ void back_change(AppletInfo *info, PanelWidget *panel);
 
 PanelData *panel_setup (PanelToplevel *toplevel);
 
-GtkWidget *make_popup_panel_menu (PanelWidget *panel);
-
-void panel_register_window_icon (void);
-
 GdkScreen *panel_screen_from_panel_widget  (PanelWidget *panel);
 
 gboolean panel_is_applet_right_stick (GtkWidget *applet);
